A data frame. There is one row for each row of the input values (see data parameter). The
columns include
the explanatory variables
.output --- the output of the model that corresponds to the explanatory value
the .lwr and .upr bounds of the prediction or confidence interval
if training data is used as the input, the .response variable and the .resid. Note that
the generic name .response is used, not the actual name of the model's response variable.